/*
 *	      UNIX is a registered trademark of AT&T
 *		Portions Copyright 1976-1990 AT&T
 *	Portions Copyright 1980-1989 Microsoft Corporation
 *   Portions Copyright (C) 1983-1991 The Santa Cruz Operation, Inc
 *		      All Rights Reserved
 *      The information in this file is provided for the exclusive use of
 *      the licensees of The Santa Cruz Operation, Inc.  Such users have the
 *      right to use, modify, and incorporate this code into other products
 *      for purposes authorized by the license agreement provided they include
 *      this notice and the associated copyright notice with any such product.
 *      The information in this file is provided "AS IS" without warranty.
 *
 *		Copyright (c) 1984, 1986, 1987, 1988 AT&T
 *			  All Rights Reserved
 *
 *	THIS IS UNPUBLISHED PROPRIETARY SOURCE CODE OF AT&T
 *	The copyright notice above does not evidence any
 *	actual or intended publication of such source code.
 *
 */

#ifndef _LIMITS_H
#define _LIMITS_H
#ifdef __STDC__
#pragma comment(exestr, "@(#) limits.h 7.3 91/08/15 ")
#else
#ident "@(#) limits.h 7.3 91/08/15 "
#endif /* __STDC__ */

#if !_STRICT_NAMES && defined(M_XPG2)
#ifdef _KR
error "XPG2 mode no longer supported, please upgrade to X/open"
#else
#error "XPG2 mode no longer supported, please upgrade to X/open"
#endif /* _KR */
#endif /* Eliminate XPG2 support */

#define CHAR_BIT                 8  /* #of bits in a "char" */

#ifdef _CHAR_UNSIGNED               /* defined with -J to msc */
#define CHAR_MAX       UCHAR_MAX  /* max integer value of a "char"*/
#define CHAR_MIN               0  /* min integer value of a "char" */
#else
#define CHAR_MAX       SCHAR_MAX  /* max integer value of a "char"*/
#define CHAR_MIN       SCHAR_MIN  /* min integer value of a "char"*/
#endif /* _CHAR_UNSIGNED */

#define INT_MAX         2147483647  /* max decimal value of an "int" */
#define INT_MIN        (-2147483648)  /* min decimal value of an "int" */
#define LONG_MAX       2147483647L  /* max decimal value of a "long" */
#define LONG_MIN      (-2147483648L)  /* min decimal value of a "long" */
#define MB_LEN_MAX             1  /* max #of bytes in a multibyte char */
#define SCHAR_MIN             (-128)  /* min integer value of a "signed char" */
#define SCHAR_MAX              127  /* max integer value of a "signed char" */
#define SHRT_MAX             32767  /* max decimal value of a "short" */
#define SHRT_MIN            (-32768)  /* min decimal value of a "short" */
#define UCHAR_MAX              255  /* max integer value of a "unsigned char" */
#define UINT_MAX       4294967295U  /* max value of 'unsigned int' */
#define ULONG_MAX     4294967295UL  /* max value of 'unsigned long' */
#define USHRT_MAX            65535  /* max value of a 'unsigned short' */

#if defined(_POSIX_SOURCE) || defined(_XOPEN_SOURCE) || !defined (__STRICT_ANSI__)
#define _POSIX_ARG_MAX     4096   /* minimum value for ARG_MAX */
#define _POSIX_CHILD_MAX      6   /* minimum value for CHILD_MAX */
#define _POSIX_LINK_MAX       8   /* minimum value for LINK_MAX */
#define _POSIX_MAX_CANON    255   /* minimum value for MAX_CANON */
#define _POSIX_MAX_INPUT    255   /* minimum value for MAX_INPUT */
#define _POSIX_NAME_MAX      14   /* minimum value for NAME_MAX */
#define _POSIX_NGROUPS_MAX    0   /* minimum value for NGROUPS_MAX */
#define _POSIX_OPEN_MAX      16   /* minimum value for OPEN_MAX */
#define _POSIX_PATH_MAX     255   /* minimum value for PATH_MAX */
#define _POSIX_PIPE_BUF     512   /* minimum value for PIPE_BUF */

/* max #of simultaneous supplementary gids per process */
#define NGROUPS_MAX           8 

#define ARG_MAX  5120 /* max length of arguments to exec */

/* The following constants are undefined in accordance with POSIX 1003.1
 * section 2.9.4. Their value is equal to or greater than the corresponding
 * _POSIX_ constant, but indeterminate at compile time. The actual value
 * supported may be obtained at runtime with sysconf()
 *
 *  CHILD_MAX
 *  OPEN_MAX
 * 
 * The following constants are undefined in accordance with POSIX 1003.1
 * section 2.9.5. Their value is equal to or greater than the corresponding
 * _POSIX_ constant, but may vary across filesystems. The exact value may be
 * determined for a give pathname at runtime with pathconf() or fpathconf().
 *
 *  LINK_MAX
 *  NAME_MAX
 *  PATH_MAX
 *
 * Note this applies XPG3.
 */

#define MAX_CANON  256 /* max #of bytes in a canonical input line */
#define MAX_INPUT  256 /* max #of bytes in a terminal input queue */
#define PIPE_BUF  8192 /* max #of bytes in an atomic-write to a pipe*/
#endif /* _POSIX_SOURCE || _XOPEN_SOURCE || !defined (__STRICT_ANSI__) */

#if !_STRICT_NAMES
#define FCHR_MAX    1048576  /* max size of a file in bytes */
#define PID_MAX       30000  /* max value for a process ID */
#define STD_BLK        1024  /* #bytes in a physical I/O block */
#define SYS_NMLN          9  /* #bytes in uname-returned strings */
#define UID_MAX       60000  /* max value for a user or group ID */
#define USI_MAX  4294967295  /* max decimal value of an "unsigned" */
#endif /* !_STRICT_NAMES */

#if defined(_XOPEN_SOURCE)
/* XOPEN defines limits.h in such a way that not all of the defines 
 * that exist in float.h are visible. So we use this _XOPEN_KLUDGE
 * macro to keep the definition of these macros in float.h to avoid
 * dupliating them. This is probably a bug in XOPEN.
 */
#define _XOPEN_KLUDGE
#include <float.h>
#undef _XOPEN_KLUDGE
#endif /* _XOPEN_SOURCE */

#if defined(_XOPEN_SOURCE) || !defined (__STRICT_ANSI__)
#define LONG_BIT         32  /* #of bits in a "long" */
#ifndef TMP_MAX
#define TMP_MAX 17576    /* max #of unique names generated by tmpnam() */
#endif /* TMP_MAX */
#define NZERO		 20
#endif /* _XOPEN_SOURCE || !defined (__STRICT_ANSI__) */

#ifdef _M_INTERNAT
#define NL_LANGMAX       14  /* max number of bytes in a LANG name */
#define NL_ARGMAX         9  /* Max value of 'digit' */
#define NL_MSGMAX     32767  /* max message number */
#define NL_SETMAX       255  /* max set number */
#define NL_TEXTMAX      255  /* Max no. of bytes in a msg string */
#define NL_NMAX           0  /* max #bytes in N-to-1 mapping characters */
#endif /* _M_INTERNAT */

#if defined(_XOPEN_SOURCE) || !_STRICT_NAMES
#define PASS_MAX          8  /* max #of characters in a password */
#define WORD_BIT         32  /* #of bits in a "word" or "int" */
#endif /* defined(_XOPEN_SOURCE) || !defined (__STRICT_ANSI__)*/

#endif /* _LIMITS_H */

